@@ -154,9 +154,12 @@ class BaseDiscovery:
 
         while "/" in path:
             path = path.rsplit("/", 1)[0]
+            path_wild = path.replace("*", "")
             for match in chain(
                 self.finder.filter_files(new_name, path),
+                self.finder.filter_files(new_name, path_wild),
                 self.finder.filter_files(self.new_base_mask, path),
+                self.finder.filter_files(self.new_base_mask, path_wild),
             ):
                 result["new_base"] = "/".join(match.parts)
                 return
@@ -244,7 +247,7 @@ class BaseDiscovery:
                 wildcard = self.get_wildcard(part)
                 if wildcard:
                     mask = parts[:]
-                    match = re.compile("(^|[._-]){}($|[._-])".format(re.escape(part)))
+                    match = re.compile(f"(^|[._-]){re.escape(part)}($|[._-])")
                     for i, current in enumerate(mask):
                         if match.findall(current):
                             skip.add(i)
