@@ -1,5 +1,5 @@
 #
-# Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
+# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
 #
 # This file is part of Weblate translation-finder
 # <https://github.com/WeblateOrg/translation-finder>
@@ -21,9 +21,11 @@
 
 from configparser import RawConfigParser
 
+from ..api import register_discovery
 from .base import BaseDiscovery
 
 
+@register_discovery
 class TransifexDiscovery(BaseDiscovery):
     """Transifex configuration discovery."""
 
