@@ -38,6 +38,7 @@ from .discovery.files import (
     QtDiscovery,
     RCDiscovery,
     RESXDiscovery,
+    StringsdictDiscovery,
     TOMLDiscovery,
     WebExtensionDiscovery,
     XliffDiscovery,
@@ -104,12 +105,19 @@ class GetttetTest(DiscoveryTestCase):
                     "desktop-docs/gpl/sr@latin/sr@latin.po",
                     "po/jp/rawhide/pages/welcome/Welcome.po",
                     "pot/rawhide/pages/welcome/Welcome.pot",
+                    "de/LC_MESSAGES/pot_not_honored.po",
+                    "pot_not_honored.pot",
                 ]
             )
         )
         self.assert_discovery(
             discovery.discover(),
             [
+                {
+                    "file_format": "po",
+                    "filemask": "*/LC_MESSAGES/pot_not_honored.po",
+                    "new_base": "pot_not_honored.pot",
+                },
                 {
                     "filemask": "locales/*/messages.po",
                     "file_format": "po",
@@ -601,6 +609,34 @@ class OSXTest(DiscoveryTestCase):
         )
 
 
+class StringsdictTest(DiscoveryTestCase):
+    def test_basic(self):
+        discovery = StringsdictDiscovery(
+            self.get_finder(
+                [
+                    "App/Resources/en.lproj/Localizable.stringsdict",
+                    "App/Resources/Base.lproj/Other.stringsdict",
+                    "App/Resources/ru.lproj/Third.stringsdict",
+                ]
+            )
+        )
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "App/Resources/*.lproj/Localizable.stringsdict",
+                    "file_format": "stringsdict",
+                    "template": "App/Resources/en.lproj/Localizable.stringsdict",
+                },
+                {
+                    "filemask": "App/Resources/*.lproj/Other.stringsdict",
+                    "file_format": "stringsdict",
+                    "template": "App/Resources/Base.lproj/Other.stringsdict",
+                },
+            ],
+        )
+
+
 class JavaTest(DiscoveryTestCase):
     def test_basic(self):
         discovery = JavaDiscovery(
